==> media_from_images-1.0.0.tar.gz: media_from_images/src/Form/MediaFromImagesAdminForm.php <==
<?php

namespace Drupal\media_from_images\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\media_from_images\MediaFromImagesServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Admin form for Media From Images module.
 */
class MediaFromImagesAdminForm extends FormBase {

  /**
   * The media from images service.
   *
   * @var \Drupal\media_from_images\MediaFromImagesServiceInterface
   */
  protected MediaFromImagesServiceInterface $mediaFromImagesService;

  /**
   * Constructs a MediaFromImagesAdminForm object.
   *
   * @param \Drupal\media_from_images\MediaFromImagesServiceInterface $media_from_images_service
   *   The media from images service.
   */
  public function __construct(MediaFromImagesServiceInterface $media_from_images_service) {
    $this->mediaFromImagesService = $media_from_images_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\media_from_images\MediaFromImagesServiceInterface $mediaFromServices */
    $mediaFromServices = $container->get('media_from_images.service');
    return new static(
      $mediaFromServices
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'media_from_images_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['#attached']['library'][] = 'core/drupal.tableheader';

    // Get statistics.
    $total_files = count($this->mediaFromImagesService->getImageFileIds());
    $files_without_media = $this->mediaFromImagesService->countFilesWithoutMediaEntities();
    $unattached_media = $this->mediaFromImagesService->countUnattachedMediaEntities();
    $entries = $this->mediaFromImagesService->getMediaHashEntries();
    $is_batch_running = $this->mediaFromImagesService->isBatchOperationRunning();

    // Statistics section.
    $form['statistics'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Statistics'),
    ];

    $form['statistics']['stats'] = [
      '#type' => 'item',
      '#markup' => $this->t('
        <div class="media-from-images-stats">
          <p><strong>Total image files:</strong> @total</p>
          <p><strong>Files without media entities:</strong> @without_media</p>
          <p><strong>Unattached media entities:</strong> @unattached_media</p>
          <p><strong>Tracked media entities:</strong> @tracked</p>
          @operation_status
        </div>
      ', [
        '@total' => $total_files,
        '@without_media' => $files_without_media,
        '@unattached_media' => $unattached_media,
        '@tracked' => count($entries),
        '@operation_status' => $is_batch_running ? '<p><strong>Status:</strong> Batch operation is currently running</p>' : '',
      ]),
    ];

    // Show warning if operation is running.
    if ($is_batch_running) {
      $form['operation_warning'] = [
        '#type' => 'container',
        '#attributes' => ['class' => ['messages', 'messages--warning']],
        'message' => [
          '#markup' => $this->t('<strong>Warning:</strong> A batch operation is currently running. Please wait for it to complete before starting another operation.'),
        ],
      ];
    }

    // Batch processing section.
    if ($files_without_media > 0) {
      $form['batch_processing'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Batch Processing'),
      ];

      $form['batch_processing']['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('There are @count image files that do not have corresponding media entities. Click the button below to create media entities for all of them.', [
          '@count' => $files_without_media,
        ]),
      ];

      $form['batch_processing']['process'] = [
        '#type' => 'submit',
        '#value' => $this->t('Create Media Entities (@count files)', ['@count' => $files_without_media]),
        '#submit' => ['::submitBatchProcess'],
        '#disabled' => $is_batch_running,
      ];
    }

    // Attach unattached media section.
    if ($unattached_media > 0) {
      $form['attach_unattached'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Attach Unattached Media'),
      ];

      $form['attach_unattached']['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('There are @count existing media entities that are not tracked in the hash table. Click the button below to attach them to the tracking system.', [
          '@count' => $unattached_media,
        ]),
      ];

      $form['attach_unattached']['attach'] = [
        '#type' => 'submit',
        '#value' => $this->t('Attach Media Entities (@count entities)', ['@count' => $unattached_media]),
        '#submit' => ['::submitAttachUnattached'],
        '#disabled' => $is_batch_running,
      ];
    }

    // Media hash entries table.
    if (!empty($entries)) {
      $form['entries'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Media Hash Entries'),
      ];

      $header = [
        $this->t('Media ID'),
        $this->t('Media Name'),
        $this->t('File ID'),
        $this->t('Filename'),
        $this->t('File Size'),
        $this->t('Hash (truncated)'),
      ];

      $rows = [];
      foreach ($entries as $entry) {
        // Create media link.
        $media_display = $entry['media_link']
          ? Link::fromTextAndUrl($entry['media_name'], $entry['media_link'])->toString()
          : $entry['media_name'];

        // Create file link to the actual image.
        $file_display = $entry['file_link']
          ? Markup::create('<a href="' . htmlspecialchars($entry['file_link'], ENT_QUOTES, 'UTF-8') . '" target="_blank">' . htmlspecialchars($entry['filename'], ENT_QUOTES, 'UTF-8') . '</a>')
          : htmlspecialchars($entry['filename'], ENT_QUOTES, 'UTF-8');

        $rows[] = [
          $entry['media_id'],
          ['data' => ['#markup' => $media_display]],
          $entry['file_id'],
          ['data' => ['#markup' => $file_display]],
          $entry['filesize'],
          substr($entry['hash'], 0, 16) . '...',
        ];
      }

      $form['entries']['table'] = [
        '#type' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#sticky' => TRUE,
        '#empty' => $this->t('No media hash entries found.'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    // Check if a batch operation is already running.
    if ($this->mediaFromImagesService->isBatchOperationRunning()) {
      $form_state->setErrorByName('', $this->t('A batch operation is currently running. Please wait for it to complete.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Default submit handler - not used in this form.
  }

  /**
   * Submit handler for batch processing.
   */
  public function submitBatchProcess(array &$form, FormStateInterface $form_state) {
    $this->mediaFromImagesService->startBatchProcess();
    $this->messenger()->addStatus($this->t('Batch process started. You will be redirected when complete.'));
  }

  /**
   * Submit handler for attaching unattached media entities.
   */
  public function submitAttachUnattached(array &$form, FormStateInterface $form_state) {
    $this->mediaFromImagesService->startAttachUnattachedProcess();
    $this->messenger()->addStatus($this->t('Attach process started. You will be redirected when complete.'));
  }

}

==> media_from_images-1.0.1.tar.gz: media_from_images/src/Form/MediaFromImagesAdminForm.php <==
<?php

namespace Drupal\media_from_images\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\media_from_images\MediaFromImagesServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Admin form for Media From Images module.
 */
class MediaFromImagesAdminForm extends FormBase {

  /**
   * The media from images service.
   *
   * @var \Drupal\media_from_images\MediaFromImagesServiceInterface
   */
  protected MediaFromImagesServiceInterface $mediaFromImagesService;

  /**
   * Constructs a MediaFromImagesAdminForm object.
   *
   * @param \Drupal\media_from_images\MediaFromImagesServiceInterface $media_from_images_service
   *   The media from images service.
   */
  public function __construct(MediaFromImagesServiceInterface $media_from_images_service) {
    $this->mediaFromImagesService = $media_from_images_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\media_from_images\MediaFromImagesServiceInterface $mediaFromServices */
    $mediaFromServices = $container->get('media_from_images.service');
    return new static(
      $mediaFromServices
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'media_from_images_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['#attached']['library'][] = 'core/drupal.tableheader';

    // Get statistics.
    $total_files = count($this->mediaFromImagesService->getImageFileIds());
    $files_without_media = $this->mediaFromImagesService->countFilesWithoutMediaEntities();
    $unattached_media = $this->mediaFromImagesService->countUnattachedMediaEntities();
    $total_entries = $this->mediaFromImagesService->countMediaHashEntries();
    $is_batch_running = $this->mediaFromImagesService->isBatchOperationRunning();

    // Set up pagination.
    $items_per_page = 50;
    $current_page = \Drupal::request()->query->get('page', 0);
    $offset = $current_page * $items_per_page;

    // Get paginated entries.
    $entries = $this->mediaFromImagesService->getMediaHashEntries($items_per_page, $offset);

    // Statistics section.
    $form['statistics'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Statistics'),
    ];

    $form['statistics']['stats'] = [
      '#type' => 'item',
      '#markup' => $this->t('
        <div class="media-from-images-stats">
          <p><strong>Total image files:</strong> @total</p>
          <p><strong>Files without media entities:</strong> @without_media</p>
          <p><strong>Unattached media entities:</strong> @unattached_media</p>
          <p><strong>Tracked media entities:</strong> @tracked</p>
          @operation_status
        </div>
      ', [
        '@total' => $total_files,
        '@without_media' => $files_without_media,
        '@unattached_media' => $unattached_media,
        '@tracked' => $total_entries,
        '@operation_status' => $is_batch_running ? '<p><strong>Status:</strong> Batch operation is currently running</p>' : '',
      ]),
    ];

    // Show warning if operation is running.
    if ($is_batch_running) {
      $form['operation_warning'] = [
        '#type' => 'container',
        '#attributes' => ['class' => ['messages', 'messages--warning']],
        'message' => [
          '#markup' => $this->t('<strong>Warning:</strong> A batch operation is currently running. Please wait for it to complete before starting another operation.'),
        ],
      ];
    }

    // Batch processing section.
    if ($files_without_media > 0) {
      $form['batch_processing'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Batch Processing'),
      ];

      $form['batch_processing']['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('There are @count image files that do not have corresponding media entities. Click the button below to create media entities for all of them.', [
          '@count' => $files_without_media,
        ]),
      ];

      $form['batch_processing']['process'] = [
        '#type' => 'submit',
        '#value' => $this->t('Create Media Entities (@count files)', ['@count' => $files_without_media]),
        '#submit' => ['::submitBatchProcess'],
        '#disabled' => $is_batch_running,
      ];
    }

    // Attach unattached media section.
    if ($unattached_media > 0) {
      $form['attach_unattached'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Attach Unattached Media'),
      ];

      $form['attach_unattached']['description'] = [
        '#type' => 'item',
        '#markup' => $this->t('There are @count existing media entities that are not tracked in the hash table. Click the button below to attach them to the tracking system.', [
          '@count' => $unattached_media,
        ]),
      ];

      $form['attach_unattached']['attach'] = [
        '#type' => 'submit',
        '#value' => $this->t('Attach Media Entities (@count entities)', ['@count' => $unattached_media]),
        '#submit' => ['::submitAttachUnattached'],
        '#disabled' => $is_batch_running,
      ];
    }

    // Media hash entries table.
    if ($total_entries > 0) {
      $form['entries'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Media Hash Entries (@showing of @total)', [
          '@showing' => count($entries),
          '@total' => $total_entries,
        ]),
      ];

      $header = [
        $this->t('Media ID'),
        $this->t('Media Name'),
        $this->t('File ID'),
        $this->t('Filename'),
        $this->t('File Size'),
        $this->t('Hash (truncated)'),
      ];

      $rows = [];
      foreach ($entries as $entry) {
        // Create media link.
        $media_display = $entry['media_link']
          ? Link::fromTextAndUrl($entry['media_name'], $entry['media_link'])->toString()
          : $entry['media_name'];

        // Create file link to the actual image.
        $file_display = $entry['file_link']
          ? Markup::create('<a href="' . htmlspecialchars($entry['file_link'], ENT_QUOTES, 'UTF-8') . '" target="_blank">' . htmlspecialchars($entry['filename'], ENT_QUOTES, 'UTF-8') . '</a>')
          : htmlspecialchars($entry['filename'], ENT_QUOTES, 'UTF-8');

        $rows[] = [
          $entry['media_id'],
          ['data' => ['#markup' => $media_display]],
          $entry['file_id'],
          ['data' => ['#markup' => $file_display]],
          $entry['filesize'],
          substr($entry['hash'], 0, 16) . '...',
        ];
      }

      $form['entries']['table'] = [
        '#type' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#sticky' => TRUE,
        '#empty' => $this->t('No media hash entries found.'),
      ];

      // Set up and add pager.
      if ($total_entries > $items_per_page) {
        pager_default_initialize($total_entries, $items_per_page);
        $form['entries']['pager'] = [
          '#type' => 'pager',
        ];
      }
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    // Check if a batch operation is already running.
    if ($this->mediaFromImagesService->isBatchOperationRunning()) {
      $form_state->setErrorByName('', $this->t('A batch operation is currently running. Please wait for it to complete.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Default submit handler - not used in this form.
  }

  /**
   * Submit handler for batch processing.
   */
  public function submitBatchProcess(array &$form, FormStateInterface $form_state) {
    $this->mediaFromImagesService->startBatchProcess();
    $this->messenger()->addStatus($this->t('Batch process started. You will be redirected when complete.'));
  }

  /**
   * Submit handler for attaching unattached media entities.
   */
  public function submitAttachUnattached(array &$form, FormStateInterface $form_state) {
    $this->mediaFromImagesService->startAttachUnattachedProcess();
    $this->messenger()->addStatus($this->t('Attach process started. You will be redirected when complete.'));
  }

}
